@@ -1,7 +1,7 @@
 <?php
 #-------------------------------------------------------------------------
 # Module: MetaMax - a pedantic "starting point" module
-# Version: 1.0, oliverseddon
+# Version: 2.1.5, oliverseddon
 #
 #-------------------------------------------------------------------------
 # CMS - CMS Made Simple is (c) 2010 by Ted Kulp (wishy@cmsmadesimple.org)
@@ -41,7 +41,7 @@ class MetaMax extends CMSModule
 
   function GetVersion()
   {
-    return '2.1.4';
+    return '2.1.5';
   }
 
   function GetHelp()
@@ -56,7 +56,7 @@ class MetaMax extends CMSModule
 
   function GetAuthorEmail()
   {
-    return 'oliver@threefold.co.uk';
+    return 'oliverseddon@me.com';
   }
 
   function GetChangeLog()
@@ -119,7 +119,7 @@ class MetaMax extends CMSModule
 
   function MaximumCMSVersion()
   {
-    return "1.15";
+    return "2.5";
   }
 
   function InitializeAdmin()
