@@ -13,8 +13,8 @@ $tmp = $this->GetPreference('detail_returnid',-1);
 $hm =& $gCms->GetHierarchyManager();
 $page_meta = cms_utils::get_current_content();
 $curalias = cms_utils::get_current_alias();
-$curnode =& $hm->getNodeByAlias($curalias);
-$curcontent =& $curnode->GetContent();
+$curnode = $hm->getNodeByAlias($curalias);
+$curcontent = $curnode->GetContent();
 $modified_date = $curcontent->GetModifiedDate();
 $modified_date = date('Y-m-d\TH:i:sP',$modified_date);
 $currentYear = date('Y');
